//--------------------------------------------------------------
// File     : main.c
// Datum    : 17.05.2015
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// Board    : STM32F429-Board von UB (Version 1.0)
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Hauptprogramm
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------
// Beschreibung :
// LoLevel-Test vom eigenbau STM32F429-Board von UB (Version 1.0)
//
// test der RTC per externem 32kHz Quarz vom STM32F429-Board
//
// Statusausgabe per COM-6 (3,3V UART) 115200 Baud
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_systick.h"
#include "stm32_ub_uart.h"
#include "stm32_ub_rtc.h"
#include <stdio.h>



int main(void)
{
  uint8_t old_sek=0;
  char buf[50];

  SystemInit(); // Quarz Einstellungen aktivieren

  // init vom sytsick
  UB_Systick_Init();

  // init der uart
  UB_Uart_Init();

  // powerOn string
  UB_Uart_SendString(COM6,"F429-Board",CRLF);
  UB_Uart_SendString(COM6,"RTC-Check",CRLF);

  // Init und start der RTC
  UB_RTC_Init();

  UB_Uart_SendString(COM6,"RTC running...",CRLF);


  while(1)
  {
    // aktuelle RTC-Zeit auslesen
    UB_RTC_GetClock(RTC_DEC);
    if(UB_RTC.sek!=old_sek) {
      // wenn eine Sekunde um ist
      old_sek=UB_RTC.sek;
      sprintf(buf,"RTC time : %d[sec]",old_sek);
      UB_Uart_SendString(COM6,buf,CRLF);
    }
  }
}

